nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

OutSel1

Struct OutSel1 

#[repr(transparent)]
pub struct OutSel1(pub u32);
Trigger Source IN16 to IN31 selector

Tuple Fields

0: u32

Implementations

Source

impl OutSel1

pub const fn in16_seln(&self) -> u8

Selects SPC VDD_SYS_LVD detect as a trigger source.

pub const fn set_in16_seln(&mut self, val: u8)

Selects SPC VDD_SYS_LVD detect as a trigger source.

pub const fn in17_seln(&self) -> u8

Selects SPC VDD_IO_LVD detect as a trigger source.

pub const fn set_in17_seln(&mut self, val: u8)

Selects SPC VDD_IO_LVD detect as a trigger source.

pub const fn in18_seln(&self) -> u8

Reserved.

pub const fn set_in18_seln(&mut self, val: u8)

Reserved.

pub const fn in19_seln(&self) -> u8

Selects VBAT temperature tamper output event as a trigger source.

pub const fn set_in19_seln(&mut self, val: u8)

Selects VBAT temperature tamper output event as a trigger source.

pub const fn in20_seln(&self) -> u8

Selects VBAT clock tamper output event as a trigger source.

pub const fn set_in20_seln(&mut self, val: u8)

Selects VBAT clock tamper output event as a trigger source.

pub const fn in21_seln(&self) -> u8

Selects INTM interrupt monitor error 0 event as a trigger source.

pub const fn set_in21_seln(&mut self, val: u8)

Selects INTM interrupt monitor error 0 event as a trigger source.

pub const fn in22_seln(&self) -> u8

Selects INTM interrupt monitor error 1 event as a trigger source.

pub const fn set_in22_seln(&mut self, val: u8)

Selects INTM interrupt monitor error 1 event as a trigger source.

pub const fn in23_seln(&self) -> u8

Selects INTM interrupt monitor error 2 event as a trigger source.

pub const fn set_in23_seln(&mut self, val: u8)

Selects INTM interrupt monitor error 2 event as a trigger source.

pub const fn in24_seln(&self) -> u8

Selects INTM interrupt monitor error 3 event as a trigger source.

pub const fn set_in24_seln(&mut self, val: u8)

Selects INTM interrupt monitor error 3 event as a trigger source.

pub const fn in25_seln(&self) -> u8

Selects MSF SOCTRIM 0 ECC error event as a trigger source.

pub const fn set_in25_seln(&mut self, val: u8)

Selects MSF SOCTRIM 0 ECC error event as a trigger source.

pub const fn in26_seln(&self) -> u8

Selects MSF SOCTRIM 1 ECC error event as a trigger source.

pub const fn set_in26_seln(&mut self, val: u8)

Selects MSF SOCTRIM 1 ECC error event as a trigger source.

pub const fn in27_seln(&self) -> u8

Selects MSF SOCTRIM 2 ECC error event as a trigger source.

pub const fn set_in27_seln(&mut self, val: u8)

Selects MSF SOCTRIM 2 ECC error event as a trigger source.

pub const fn in28_seln(&self) -> u8

Selects MSF SOCTRIM 3 ECC error event as a trigger source.

pub const fn set_in28_seln(&mut self, val: u8)

Selects MSF SOCTRIM 3 ECC error event as a trigger source.

pub const fn in29_seln(&self) -> u8

Selects MSF SOCTRIM 4 ECC error event as a trigger source.

pub const fn set_in29_seln(&mut self, val: u8)

Selects MSF SOCTRIM 4 ECC error event as a trigger source.

pub const fn in30_seln(&self) -> u8

Selects MSF SOCTRIM 5 ECC error event as a trigger source.

pub const fn set_in30_seln(&mut self, val: u8)

Selects MSF SOCTRIM 5 ECC error event as a trigger source.

pub const fn in31_seln(&self) -> u8

Selects MSF SOCTRIM 6 ECC error event as a trigger source.

pub const fn set_in31_seln(&mut self, val: u8)

Selects MSF SOCTRIM 6 ECC error event as a trigger source.